@@ -103,10 +103,9 @@ class Preferences(Adw.PreferencesWindow):
 
         nconvention_group.add(exec_as_name_switch)
 
-        preview_appimage_files = self.create_boolean_settings_entry(
-            _('Preview hashes for new apps before loading metadata'),
-            'preview-before-opening-app',
-            _('If enabled, a preview of the file you are trying to open is shown.\nDisable only if you trust your sources: malicious apps could execute code when loading the metadata.')
+        preview_minimal_ui = self.create_boolean_settings_entry(
+            _('Preview new apps in a minimal UI'),
+            'preview-minimal-ui',
         )
         
         block_appimage_extract = self.create_boolean_settings_entry(
@@ -115,7 +114,7 @@ class Preferences(Adw.PreferencesWindow):
             _('If enabled, the app will try to load an Appimage without using the built-in appimage-extract command.\nDisable only if you trust your sources: malicious apps could execute code when loading the metadata.')
         )
 
-        general_preference_group.add(preview_appimage_files)
+        general_preference_group.add(preview_minimal_ui)
         general_preference_group.add(block_appimage_extract)
 
         # debugging group
